@@ -2,21 +2,19 @@
  * playlist-utils.c
  * Copyright 2009-2011 John Lindgren
  *
- * This file is part of Audacious.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
  *
- * Audacious is free software: you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation, version 2 or version 3 of the License.
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions, and the following disclaimer.
  *
- * Audacious is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * 2. Redistributions in binary form must reproduce the above copyright notice,
+ *    this list of conditions, and the following disclaimer in the documentation
+ *    provided with the distribution.
  *
- * You should have received a copy of the GNU General Public License along with
- * Audacious. If not, see <http://www.gnu.org/licenses/>.
- *
- * The Audacious team does not consider modular code linking to Audacious or
- * using our public API to be a derived work.
+ * This software is provided "as is" and without any warranty, express or
+ * implied. In no event shall the authors be liable for any damages arising from
+ * the use of this software.
  */
 
 #include <dirent.h>
@@ -100,6 +98,11 @@ static int tuple_compare_track (const Tuple * a, const Tuple * b)
     return tuple_compare_int (a, b, FIELD_TRACK_NUMBER);
 }
 
+static int tuple_compare_length (const Tuple * a, const Tuple * b)
+{
+    return tuple_compare_int (a, b, FIELD_LENGTH);
+}
+
 static const PlaylistStringCompareFunc filename_comparisons[] = {
  [PLAYLIST_SORT_PATH] = string_compare_encoded,
  [PLAYLIST_SORT_FILENAME] = filename_compare_basename,
@@ -108,7 +111,8 @@ static const PlaylistStringCompareFunc filename_comparisons[] = {
  [PLAYLIST_SORT_ARTIST] = NULL,
  [PLAYLIST_SORT_DATE] = NULL,
  [PLAYLIST_SORT_TRACK] = NULL,
- [PLAYLIST_SORT_FORMATTED_TITLE] = NULL};
+ [PLAYLIST_SORT_FORMATTED_TITLE] = NULL,
+ [PLAYLIST_SORT_LENGTH] = NULL};
 
 static const PlaylistTupleCompareFunc tuple_comparisons[] = {
  [PLAYLIST_SORT_PATH] = NULL,
@@ -118,7 +122,8 @@ static const PlaylistTupleCompareFunc tuple_comparisons[] = {
  [PLAYLIST_SORT_ARTIST] = tuple_compare_artist,
  [PLAYLIST_SORT_DATE] = tuple_compare_date,
  [PLAYLIST_SORT_TRACK] = tuple_compare_track,
- [PLAYLIST_SORT_FORMATTED_TITLE] = NULL};
+ [PLAYLIST_SORT_FORMATTED_TITLE] = NULL,
+ [PLAYLIST_SORT_LENGTH] = tuple_compare_length};
 
 static const PlaylistStringCompareFunc title_comparisons[] = {
  [PLAYLIST_SORT_PATH] = NULL,
@@ -128,7 +133,8 @@ static const PlaylistStringCompareFunc title_comparisons[] = {
  [PLAYLIST_SORT_ARTIST] = NULL,
  [PLAYLIST_SORT_DATE] = NULL,
  [PLAYLIST_SORT_TRACK] = NULL,
- [PLAYLIST_SORT_FORMATTED_TITLE] = string_compare};
+ [PLAYLIST_SORT_FORMATTED_TITLE] = string_compare,
+ [PLAYLIST_SORT_LENGTH] = NULL};
 
 void playlist_sort_by_scheme (int playlist, int scheme)
 {
@@ -473,8 +479,8 @@ void save_playlists (bool_t exiting)
 {
     save_playlists_real ();
 
-    /* on exit, save resume time if resume feature is enabled */
-    if (state_changed || (exiting && get_bool (NULL, "resume_playback_on_startup")))
+    /* on exit, save resume states */
+    if (state_changed || exiting)
     {
         playlist_save_state ();
         state_changed = FALSE;
