@@ -2,21 +2,19 @@
  * plugin-registry.c
  * Copyright 2009-2011 John Lindgren
  *
- * This file is part of Audacious.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
  *
- * Audacious is free software: you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation, version 2 or version 3 of the License.
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions, and the following disclaimer.
  *
- * Audacious is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * 2. Redistributions in binary form must reproduce the above copyright notice,
+ *    this list of conditions, and the following disclaimer in the documentation
+ *    provided with the distribution.
  *
- * You should have received a copy of the GNU General Public License along with
- * Audacious. If not, see <http://www.gnu.org/licenses/>.
- *
- * The Audacious team does not consider modular code linking to Audacious or
- * using our public API to be a derived work.
+ * This software is provided "as is" and without any warranty, express or
+ * implied. In no event shall the authors be liable for any damages arising from
+ * the use of this software.
  */
 
 /* While the registry is being built (during early startup) or destroyed (during
@@ -34,14 +32,14 @@
 #include <libaudcore/audstrings.h>
 
 #include "debug.h"
+#include "i18n.h"
 #include "interface.h"
 #include "misc.h"
 #include "plugin.h"
 #include "plugins.h"
-#include "util.h"
 
 #define FILENAME "plugin-registry"
-#define FORMAT 6
+#define FORMAT 8
 
 typedef struct {
     GList * schemes;
@@ -61,10 +59,11 @@ struct PluginHandle {
     bool_t confirmed, loaded;
     int timestamp, type;
     Plugin * header;
-    char * name;
+    char * name, * domain;
     int priority;
     bool_t has_about, has_configure, enabled;
     GList * watches;
+    void * misc;
 
     union {
         TransportPluginData t;
@@ -109,11 +108,13 @@ static PluginHandle * plugin_new (char * path, bool_t confirmed, bool_t
     plugin->type = type;
     plugin->header = header;
     plugin->name = NULL;
+    plugin->domain = NULL;
     plugin->priority = 0;
     plugin->has_about = FALSE;
     plugin->has_configure = FALSE;
     plugin->enabled = FALSE;
     plugin->watches = NULL;
+    plugin->misc = NULL;
 
     if (type == PLUGIN_TYPE_TRANSPORT)
     {
@@ -143,30 +144,22 @@ static void plugin_free (PluginHandle * plugin)
 {
     plugin_list = g_list_remove (plugin_list, plugin);
 
-    g_list_foreach (plugin->watches, (GFunc) g_free, NULL);
-    g_list_free (plugin->watches);
+    g_list_free_full (plugin->watches, g_free);
 
     if (plugin->type == PLUGIN_TYPE_TRANSPORT)
-    {
-        g_list_foreach (plugin->u.t.schemes, (GFunc) g_free, NULL);
-        g_list_free (plugin->u.t.schemes);
-    }
+        g_list_free_full (plugin->u.t.schemes, g_free);
     else if (plugin->type == PLUGIN_TYPE_PLAYLIST)
-    {
-        g_list_foreach (plugin->u.p.exts, (GFunc) g_free, NULL);
-        g_list_free (plugin->u.p.exts);
-    }
+        g_list_free_full (plugin->u.p.exts, g_free);
     else if (plugin->type == PLUGIN_TYPE_INPUT)
     {
         for (int key = 0; key < INPUT_KEYS; key ++)
-        {
-            g_list_foreach (plugin->u.i.keys[key], (GFunc) g_free, NULL);
-            g_list_free (plugin->u.i.keys[key]);
-        }
+            g_list_free_full (plugin->u.i.keys[key], g_free);
     }
 
     g_free (plugin->path);
     g_free (plugin->name);
+    g_free (plugin->domain);
+    g_free (plugin->misc);
     g_free (plugin);
 }
 
@@ -210,6 +203,10 @@ static void plugin_save (PluginHandle * plugin, FILE * handle)
     fprintf (handle, "%s %s\n", plugin_type_names[plugin->type], plugin->path);
     fprintf (handle, "stamp %d\n", plugin->timestamp);
     fprintf (handle, "name %s\n", plugin->name);
+
+    if (plugin->domain)
+        fprintf (handle, "domain %s\n", plugin->domain);
+
     fprintf (handle, "priority %d\n", plugin->priority);
     fprintf (handle, "about %d\n", plugin->has_about);
     fprintf (handle, "config %d\n", plugin->has_configure);
@@ -343,6 +340,8 @@ FOUND:
 
     if ((plugin->name = parse_string ("name")))
         parse_next (handle);
+    if ((plugin->domain = parse_string ("domain")))
+        parse_next (handle);
     if (parse_integer ("priority", & plugin->priority))
         parse_next (handle);
     if (parse_integer ("about", & plugin->has_about))
@@ -406,7 +405,7 @@ int plugin_compare (PluginHandle * a, PluginHandle * b)
         return 1;
 
     int diff;
-    if ((diff = string_compare (a->name, b->name)))
+    if ((diff = string_compare (dgettext (a->domain, a->name), dgettext (b->domain, b->name))))
         return diff;
 
     return string_compare (a->path, b->path);
@@ -454,67 +453,24 @@ PluginHandle * plugin_lookup_basename (const char * basename)
     return node ? node->data : NULL;
 }
 
-void plugin_register (const char * path)
+static void plugin_get_info (PluginHandle * plugin, bool_t new)
 {
-    PluginHandle * plugin = plugin_lookup (path);
-    if (! plugin)
-    {
-        AUDDBG ("New plugin: %s\n", path);
-        plugin_load (path);
-        return;
-    }
-
-    int timestamp = file_get_mtime (path);
-    g_return_if_fail (timestamp >= 0);
-
-    AUDDBG ("Register plugin: %s\n", path);
-    plugin->confirmed = TRUE;
-
-    if (plugin->timestamp == timestamp)
-        return;
-
-    AUDDBG ("Rescan plugin: %s\n", path);
-    plugin->timestamp = timestamp;
-    plugin_load (path);
-}
-
-void plugin_register_loaded (const char * path, Plugin * header)
-{
-    AUDDBG ("Loaded plugin: %s\n", path);
-    PluginHandle * plugin = plugin_lookup (path);
-    bool_t new = FALSE;
-
-    if (plugin)
-    {
-        g_return_if_fail (plugin->type == header->type);
-
-        plugin->loaded = TRUE;
-        plugin->header = header;
-
-        if (registry_locked)
-            return;
-    }
-    else
-    {
-        g_return_if_fail (! registry_locked);
-
-        int timestamp = file_get_mtime (path);
-        g_return_if_fail (timestamp >= 0);
-
-        plugin = plugin_new (g_strdup (path), TRUE, TRUE, timestamp,
-         header->type, header);
-        new = TRUE;
-    }
+    Plugin * header = plugin->header;
 
     g_free (plugin->name);
+    g_free (plugin->domain);
     plugin->name = g_strdup (header->name);
-    plugin->has_about = PLUGIN_HAS_FUNC (header, about);
-    plugin->has_configure = PLUGIN_HAS_FUNC (header, configure) ||
-     PLUGIN_HAS_FUNC (header, settings);
+    plugin->domain = PLUGIN_HAS_FUNC (header, domain) ? g_strdup (header->domain) : NULL;
+    plugin->has_about = PLUGIN_HAS_FUNC (header, about) || PLUGIN_HAS_FUNC (header, about_text);
+    plugin->has_configure = PLUGIN_HAS_FUNC (header, configure) || PLUGIN_HAS_FUNC (header, prefs);
 
     if (header->type == PLUGIN_TYPE_TRANSPORT)
     {
         TransportPlugin * tp = (TransportPlugin *) header;
+
+        g_list_free_full (plugin->u.t.schemes, g_free);
+        plugin->u.t.schemes = NULL;
+
         for (int i = 0; tp->schemes[i]; i ++)
             plugin->u.t.schemes = g_list_prepend (plugin->u.t.schemes, g_strdup
              (tp->schemes[i]));
@@ -522,6 +478,10 @@ void plugin_register_loaded (const char * path, Plugin * header)
     else if (header->type == PLUGIN_TYPE_PLAYLIST)
     {
         PlaylistPlugin * pp = (PlaylistPlugin *) header;
+
+        g_list_free_full (plugin->u.p.exts, g_free);
+        plugin->u.p.exts = NULL;
+
         for (int i = 0; pp->extensions[i]; i ++)
             plugin->u.p.exts = g_list_prepend (plugin->u.p.exts, g_strdup
              (pp->extensions[i]));
@@ -533,8 +493,7 @@ void plugin_register_loaded (const char * path, Plugin * header)
 
         for (int key = 0; key < INPUT_KEYS; key ++)
         {
-            g_list_foreach (plugin->u.i.keys[key], (GFunc) g_free, NULL);
-            g_list_free (plugin->u.i.keys[key]);
+            g_list_free_full (plugin->u.i.keys[key], g_free);
             plugin->u.i.keys[key] = NULL;
         }
 
@@ -583,6 +542,43 @@ void plugin_register_loaded (const char * path, Plugin * header)
     }
 }
 
+void plugin_register (const char * path, int timestamp)
+{
+    PluginHandle * plugin = plugin_lookup (path);
+
+    if (plugin)
+    {
+        AUDDBG ("Register plugin: %s\n", path);
+        plugin->confirmed = TRUE;
+
+        if (plugin->timestamp != timestamp)
+        {
+            AUDDBG ("Rescan plugin: %s\n", path);
+            Plugin * header = plugin_load (path);
+            if (! header || header->type != plugin->type)
+                return;
+
+            plugin->loaded = TRUE;
+            plugin->header = header;
+            plugin->timestamp = timestamp;
+
+            plugin_get_info (plugin, FALSE);
+        }
+    }
+    else
+    {
+        AUDDBG ("New plugin: %s\n", path);
+        Plugin * header = plugin_load (path);
+        if (! header)
+            return;
+
+        plugin = plugin_new (g_strdup (path), TRUE, TRUE, timestamp,
+         header->type, header);
+
+        plugin_get_info (plugin, TRUE);
+    }
+}
+
 int plugin_get_type (PluginHandle * plugin)
 {
     return plugin->type;
@@ -599,10 +595,15 @@ const void * plugin_get_header (PluginHandle * plugin)
 
     if (! plugin->loaded)
     {
-        plugin_load (plugin->path);
+        Plugin * header = plugin_load (plugin->path);
+        if (! header || header->type != plugin->type)
+            goto DONE;
+
         plugin->loaded = TRUE;
+        plugin->header = header;
     }
 
+DONE:
     pthread_mutex_unlock (& mutex);
     return plugin->header;
 }
@@ -632,7 +633,7 @@ void plugin_for_each (int type, PluginForEachFunc func, void * data)
 
 const char * plugin_get_name (PluginHandle * plugin)
 {
-    return plugin->name;
+    return dgettext (plugin->domain, plugin->name);
 }
 
 bool_t plugin_has_about (PluginHandle * plugin)
@@ -719,6 +720,14 @@ void plugin_remove_watch (PluginHandle * plugin, PluginForEachFunc func, void *
     }
 }
 
+void * plugin_get_misc_data (PluginHandle * plugin, int size)
+{
+    if (! plugin->misc)
+        plugin->misc = g_malloc0 (size);
+
+    return plugin->misc;
+}
+
 typedef struct {
     const char * scheme;
     PluginHandle * plugin;
