@@ -2,21 +2,19 @@
  * plugins-api.h
  * Copyright 2010 John Lindgren
  *
- * This file is part of Audacious.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
  *
- * Audacious is free software: you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation, version 2 or version 3 of the License.
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions, and the following disclaimer.
  *
- * Audacious is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * 2. Redistributions in binary form must reproduce the above copyright notice,
+ *    this list of conditions, and the following disclaimer in the documentation
+ *    provided with the distribution.
  *
- * You should have received a copy of the GNU General Public License along with
- * Audacious. If not, see <http://www.gnu.org/licenses/>.
- *
- * The Audacious team does not consider modular code linking to Audacious or
- * using our public API to be a derived work.
+ * This software is provided "as is" and without any warranty, express or
+ * implied. In no event shall the authors be liable for any damages arising from
+ * the use of this software.
  */
 
 /* Do not include this file directly; use misc.h instead. */
@@ -50,6 +48,8 @@ AUD_VFUNC3 (plugin_for_enabled, int, type, PluginForEachFunc, func,
 AUD_FUNC1 (const char *, plugin_get_name, PluginHandle *, plugin)
 AUD_FUNC1 (bool_t, plugin_has_about, PluginHandle *, plugin)
 AUD_FUNC1 (bool_t, plugin_has_configure, PluginHandle *, plugin)
+AUD_VFUNC1 (plugin_do_about, PluginHandle *, plugin)
+AUD_VFUNC1 (plugin_do_configure, PluginHandle *, plugin)
 
 AUD_VFUNC3 (plugin_add_watch, PluginHandle *, plugin, PluginForEachFunc,
  func, void *, data)
