@@ -1,25 +1,27 @@
-/*  Audacious - Cross-platform multimedia player
- *  Copyright (C) 2008  Audacious development team.
+/*
+ * preferences.h
+ * Copyright 2007-2011 Tomasz Moń, William Pitcock, and John Lindgren
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; under version 3 of the License.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions, and the following disclaimer.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses>.
+ * 2. Redistributions in binary form must reproduce the above copyright notice,
+ *    this list of conditions, and the following disclaimer in the documentation
+ *    provided with the distribution.
  *
- *  The Audacious team does not consider modular code linking to
- *  Audacious or using our public API to be a derived work.
+ * This software is provided "as is" and without any warranty, express or
+ * implied. In no event shall the authors be liable for any damages arising from
+ * the use of this software.
  */
 
 #ifndef AUDACIOUS_PREFERENCES_H
 #define AUDACIOUS_PREFERENCES_H
 
+#include <audacious/types.h>
+
 typedef enum {
     WIDGET_NONE,
     WIDGET_CHK_BTN,
@@ -45,27 +47,31 @@ typedef enum {
 } ValueType;
 
 typedef struct {
-    gpointer value;
-    const char *label;
+    void * value;
+    const char * label;
 } ComboBoxElements;
 
 struct _NotebookTab;
 
 struct _PreferencesWidget {
-    WidgetType type;         /* widget type */
-    char *label;             /* widget title (for SPIN_BTN it's text left to widget) */
-    gpointer cfg;            /* connected config value */
-    void (*callback) (void); /* this func will be called after value change, can be NULL */
-    char *tooltip;           /* widget tooltip, can be NULL */
+    WidgetType type;          /* widget type */
+    const char * label;       /* widget title (for SPIN_BTN it's text left to widget) */
+    void * cfg;               /* connected config value */
+    void (* callback) (void); /* this func will be called after value change, can be NULL */
+    const char * tooltip;     /* widget tooltip, can be NULL */
     bool_t child;
-    ValueType cfg_type;      /* connected value type */
-    const char * csect;     /* config file section */
-    const char * cname;     /* config file key name */
+    ValueType cfg_type;       /* connected value type */
+    const char * csect;       /* config file section */
+    const char * cname;       /* config file key name */
 
     union {
+        struct {
+            int value;
+        } radio_btn;
+
         struct {
             double min, max, step;
-            char *right_label;      /* text right to widget */
+            const char * right_label; /* text right to widget */
         } spin_btn;
 
         struct {
@@ -74,12 +80,12 @@ struct _PreferencesWidget {
         } table;
 
         struct {
-            char *stock_id;
+            const char * stock_id;
             bool_t single_line; /* FALSE to enable line wrap */
         } label;
 
         struct {
-            char *title;
+            const char * title;
         } font_btn;
 
         struct {
@@ -87,13 +93,12 @@ struct _PreferencesWidget {
         } entry;
 
         struct {
-            ComboBoxElements *elements;
+            const ComboBoxElements * elements;
             int n_elements;
-            bool_t enabled;
         } combo;
 
         struct {
-            struct _PreferencesWidget *elem;
+            const struct _PreferencesWidget * elem;
             int n_elem;
 
             bool_t horizontal;  /* FALSE gives vertical, TRUE gives horizontal aligment of child widgets */
@@ -101,7 +106,7 @@ struct _PreferencesWidget {
         } box;
 
         struct {
-            struct _NotebookTab *tabs;
+            const struct _NotebookTab * tabs;
             int n_tabs;
         } notebook;
 
@@ -116,31 +121,18 @@ struct _PreferencesWidget {
 };
 
 typedef struct _NotebookTab {
-    char *name;
-    PreferencesWidget *settings;
-    int n_settings;
+    const char * name;
+    const PreferencesWidget * widgets;
+    int n_widgets;
 } NotebookTab;
 
-typedef enum {
-    PREFERENCES_WINDOW,  /* displayed in seperate window */
-} PreferencesType;
-
 struct _PluginPreferences {
-    const char * domain;
-    const char * title;
-    const char * imgurl;
-
-    PreferencesWidget *prefs;
-    int n_prefs;
-
-    PreferencesType type;
+    const PreferencesWidget * widgets;
+    int n_widgets;
 
     void (*init)(void);
     void (*apply)(void);
-    void (*cancel)(void);
     void (*cleanup)(void);
-
-    gpointer data;    /* for internal interface use only */
 };
 
 #endif /* AUDACIOUS_PREFERENCES_H */
