@@ -1,22 +1,21 @@
 /*
- * Audacious - Tuplez compiler
+ * tuple_compiler.c
  * Copyright (c) 2007 Matti 'ccr' Hämäläinen
  * Copyright (c) 2011 John Lindgren
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; under version 3 of the License.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions, and the following disclaimer.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses>.
+ * 2. Redistributions in binary form must reproduce the above copyright notice,
+ *    this list of conditions, and the following disclaimer in the documentation
+ *    provided with the distribution.
  *
- * The Audacious team does not consider modular code linking to
- * Audacious or using our public API to be a derived work.
+ * This software is provided "as is" and without any warranty, express or
+ * implied. In no event shall the authors be liable for any damages arising from
+ * the use of this software.
  */
 
 /*
@@ -222,15 +221,16 @@ void tuple_evalnode_free(TupleEvalNode *expr)
 }
 
 
-static TupleEvalNode *tuple_compiler_pass1(int *level, TupleEvalContext *ctx, char **expression);
+static TupleEvalNode *tuple_compiler_pass1(int *level, TupleEvalContext *ctx, const char **expression);
 
 
 static bool_t tc_get_item(TupleEvalContext *ctx,
-    char **str, char *buf, gssize max,
-    char endch, bool_t *literal, char *errstr, char *item)
+    const char **str, char *buf, gssize max,
+    char endch, bool_t *literal, char *errstr, const char *item)
 {
   gssize i = 0;
-  char *s = *str, tmpendch;
+  const char *s = *str;
+  char tmpendch;
 
   if (*s == '"') {
     if (*literal == FALSE) {
@@ -307,7 +307,8 @@ static int tc_get_variable(TupleEvalContext *ctx, char *name, int type)
 }
 
 
-static bool_t tc_parse_construct(TupleEvalContext *ctx, TupleEvalNode **res, char *item, char **c, int *level, int opcode)
+static bool_t tc_parse_construct(TupleEvalContext *ctx, TupleEvalNode **res,
+ const char *item, const char **c, int *level, int opcode)
 {
   char tmps1[MAX_STR], tmps2[MAX_STR];
   bool_t literal1 = TRUE, literal2 = TRUE;
@@ -345,10 +346,11 @@ static bool_t tc_parse_construct(TupleEvalContext *ctx, TupleEvalNode **res, cha
  * A "simple" straight compilation is sufficient in first pass, later
  * passes can perform subexpression removal and other optimizations.
  */
-static TupleEvalNode *tuple_compiler_pass1(int *level, TupleEvalContext *ctx, char **expression)
+static TupleEvalNode *tuple_compiler_pass1(int *level, TupleEvalContext *ctx, const char **expression)
 {
   TupleEvalNode *res = NULL, *tmp = NULL;
-  char *c = *expression, *item, tmps1[MAX_STR];
+  const char *c = *expression, *item;
+  char tmps1[MAX_STR];
   bool_t literal, end = FALSE;
 
   (*level)++;
@@ -364,7 +366,7 @@ static TupleEvalNode *tuple_compiler_pass1(int *level, TupleEvalContext *ctx, ch
       item = c++;
       if (*c == '{') {
         int opcode;
-        char *expr = ++c;
+        const char *expr = ++c;
 
         switch (*c) {
           case '?': c++;
@@ -536,10 +538,10 @@ ret_error:
 }
 
 
-TupleEvalNode *tuple_formatter_compile(TupleEvalContext *ctx, char *expr)
+TupleEvalNode *tuple_formatter_compile(TupleEvalContext *ctx, const char *expr)
 {
   int level = 0;
-  char *tmpexpr = expr;
+  const char *tmpexpr = expr;
   TupleEvalNode *res1;
 
   res1 = tuple_compiler_pass1(&level, ctx, &tmpexpr);
