@@ -17,8 +17,6 @@
  * the use of this software.
  */
 
-#include "config.h"
-
 #include <audacious/i18n.h>
 #include <audacious/plugin.h>
 #include <audacious/plugins.h>
@@ -52,9 +50,7 @@ static void settings_cb (GtkMenuItem * settings, PluginHandle * plugin)
     if (! aud_plugin_get_enabled (plugin))
         return;
 
-    Plugin * header = aud_plugin_get_header (plugin);
-    g_return_if_fail (header != NULL);
-    header->configure ();
+    aud_plugin_do_configure (plugin);
 }
 
 static bool_t add_item_cb (PluginHandle * plugin, GtkWidget * menu)
