@@ -2,26 +2,24 @@
  * icons-stock.c
  * Copyright 2007-2010 Michael Färber and John Lindgren
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; under version 3 of the License.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions, and the following disclaimer.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses>.
+ * 2. Redistributions in binary form must reproduce the above copyright notice,
+ *    this list of conditions, and the following disclaimer in the documentation
+ *    provided with the distribution.
  *
- * The Audacious team does not consider modular code linking to
- * Audacious or using our public API to be a derived work.
+ * This software is provided "as is" and without any warranty, express or
+ * implied. In no event shall the authors be liable for any damages arising from
+ * the use of this software.
  */
 
 #include <gtk/gtk.h>
 #include <audacious/misc.h>
 
-#include "config.h"
 #include "libaudgui.h"
 
 static void load_stock_icon (char * id, char * filename,
@@ -48,14 +46,14 @@ audgui_register_stock_icons(void)
 {
     GtkIconFactory *iconfactory = gtk_icon_factory_new();
 
+    load_stock_icon(AUD_STOCK_AUDACIOUS,
+                    "audacious.png", iconfactory);
     load_stock_icon(AUD_STOCK_PLAYLIST,
                     "menu_playlist.png", iconfactory);
     load_stock_icon(AUD_STOCK_PLUGIN,
                     "menu_plugin.png", iconfactory);
     load_stock_icon(AUD_STOCK_QUEUETOGGLE,
                     "menu_queue_toggle.png", iconfactory);
-    load_stock_icon(AUD_STOCK_RANDOMIZEPL,
-                    "menu_randomize_playlist.png", iconfactory);
 
     gtk_icon_factory_add_default( iconfactory );
     g_object_unref( iconfactory );
