@@ -21,7 +21,6 @@
 #include <audacious/playlist.h>
 #include <libaudcore/hook.h>
 
-#include "config.h"
 #include "init.h"
 #include "libaudgui.h"
 #include "libaudgui-gtk.h"
@@ -62,10 +61,14 @@ EXPORT void audgui_cleanup (void)
     hook_dissociate ("playlist position", playlist_position_cb);
 
     audgui_hide_equalizer_window ();
+    audgui_infopopup_hide ();
+    audgui_infowin_hide ();
+    audgui_jump_to_time_cleanup ();
     audgui_jump_to_track_hide ();
     audgui_pixbuf_uncache ();
     audgui_playlist_manager_cleanup ();
     audgui_queue_manager_cleanup ();
+    audgui_url_opener_cleanup ();
 
     _aud_api_table = NULL;
 }
