@@ -2,20 +2,19 @@
  * libaudgui.h
  * Copyright 2007-2009 Giacomo Lozito and Tomasz Moń
 
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; under version 3 of the License.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions, and the following disclaimer.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses>.
+ * 2. Redistributions in binary form must reproduce the above copyright notice,
+ *    this list of conditions, and the following disclaimer in the documentation
+ *    provided with the distribution.
  *
- * The Audacious team does not consider modular code linking to
- * Audacious or using our public API to be a derived work.
+ * This software is provided "as is" and without any warranty, express or
+ * implied. In no event shall the authors be liable for any damages arising from
+ * the use of this software.
  */
 
 #ifndef LIBAUDGUI_H
@@ -24,10 +23,10 @@
 #include <libaudcore/core.h>
 
 /* macro defines for Audacious stock icons */
+#define AUD_STOCK_AUDACIOUS   "aud-audacious"
 #define AUD_STOCK_PLAYLIST    "aud-playlist"
 #define AUD_STOCK_PLUGIN      "aud-plugin"
 #define AUD_STOCK_QUEUETOGGLE "aud-queuetoggle"
-#define AUD_STOCK_RANDOMIZEPL "aud-randomizepl"
 
 void audgui_register_stock_icons(void);
 
@@ -58,6 +57,7 @@ void audgui_infopopup_hide (void);
 /* infowin.c */
 void audgui_infowin_show (int playlist, int entry);
 void audgui_infowin_show_current (void);
+void audgui_infowin_hide (void);
 
 /* jump-to-time.c */
 void audgui_jump_to_time (void);
