@@ -1,21 +1,20 @@
 /*
- * Copyright 2009 Paula Stanciu
+ * util.c
+ * Copyright 2009-2011 Paula Stanciu, Tony Vroon, and John Lindgren
  *
- * This file is part of Audacious.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
  *
- * Audacious is free software: you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation, version 3 of the License.
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions, and the following disclaimer.
  *
- * Audacious is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * 2. Redistributions in binary form must reproduce the above copyright notice,
+ *    this list of conditions, and the following disclaimer in the documentation
+ *    provided with the distribution.
  *
- * You should have received a copy of the GNU General Public License along with
- * Audacious. If not, see <http://www.gnu.org/licenses/>.
- *
- * The Audacious team does not consider modular code linking to Audacious or
- * using our public API to be a derived work.
+ * This software is provided "as is" and without any warranty, express or
+ * implied. In no event shall the authors be liable for any damages arising from
+ * the use of this software.
  */
 
 #include <glib.h>
@@ -178,12 +177,12 @@ bool_t cut_beginning_tag (VFSFile * handle, int64_t tag_size)
     return vfs_ftruncate (handle, offset) == 0;
 }
 
-char *convert_numericgenre_to_text(int numericgenre)
+const char *convert_numericgenre_to_text(int numericgenre)
 {
     const struct
     {
         int numericgenre;
-        char *genre;
+        const char *genre;
     }
     table[] =
     {
